@@ -8,7 +8,9 @@ class Auth0Tests(OAuth2TestsMixin, TestCase):
     provider_id = Auth0Provider.id
 
     def get_mocked_response(self):
-        return MockedResponse(200, """
+        return MockedResponse(
+            200,
+            """
             {
                 "picture": "https://secure.gravatar.com/avatar/123",
                 "email": "mr.bob@your.Auth0.server.example.com",
@@ -17,4 +19,5 @@ class Auth0Tests(OAuth2TestsMixin, TestCase):
                 "identities": [],
                 "name": "Mr Bob"
             }
-        """)
+        """,
+        )
